@@ -1,8 +1,6 @@
 #include "ptyx.h"
 #include <stdlib.h>
 
-#if OPT_HANGUL
-
 #define MAXHISTENT 40
 #define MAXHISTBUF 256
 
@@ -13,11 +11,10 @@ typedef struct {
 static HIST_ENTRY *the_history[MAXHISTENT];
 static HIST_ENTRY hist_buf[MAXHISTENT];
 
-static int history_offset;
-static int history_length;
+int history_offset;
+int history_length;
 
-void 
-history_init(void)
+void init_history()
 {
     int i;
 
@@ -27,14 +24,14 @@ history_init(void)
 
 }
 
-void 
-history_reset(void)
+void using_history()
 {
     history_offset = history_length;
 }
 
-void 
-history_add(Char *str, int len)
+void add_history(str, len)
+    Char* str;
+    int len;
 {
     int i;
     HIST_ENTRY *temp;
@@ -55,8 +52,7 @@ history_add(Char *str, int len)
     the_history[history_length-1]->line[len] = 0;
 }
 
-Char *
-history_previous(void)
+Char *previous_history ()
 {
     if (history_length == 0)
 	return NULL;
@@ -66,15 +62,10 @@ history_previous(void)
 	return the_history[--history_offset]->line;
 }
 
-Char *
-history_next(void)
+Char *next_history ()
 {
-    if (history_offset >= history_length - 1) {
-	history_offset = history_length;
+    if (history_offset >= history_length-1)
 	return NULL;
-    } else
+    else
 	return the_history[++history_offset]->line;
 }
-
-#endif /* OPT_HANGUL */
-
