@@ -1,9 +1,8 @@
 /*
- *	$Xorg: main.h,v 1.3 2000/08/17 19:55:09 cpqbld Exp $
+ *	$XConsortium: main.h,v 1.5 91/02/06 16:00:15 gildea Exp $
+ *	$XFree86: xc/programs/xterm/main.h,v 3.1 1996/01/10 05:51:41 dawes Exp $
  */
 
-/* $XFree86: xc/programs/xterm/main.h,v 3.7 2002/08/17 19:52:26 dickey Exp $ */
-
 /*
  * Copyright 1987 by Digital Equipment Corporation, Maynard, Massachusetts.
  *
@@ -27,27 +26,10 @@
  * SOFTWARE.
  */
 
-#if OPT_HANGUL
-#define DEFCLASS		"Hanterm"
-#define DEFHFONT		"-*-*-*-r-*--16-*-*-*-*-*-ksc5601.1987-0"
+#define	DEFFONT			"-schumacher-*-medium-*--16-160-*-iso8859-1"
+#define	DEFBOLDFONT		NULL 	/* no bold font uses overstriking */
+#define	DEFBORDER		2
+#ifdef HANGUL
+#define DEFHFONT 		"-daewoo-*-160-ksc5601.1987-*"
 #define DEFHBOLDFONT		NULL
-#define DEFFONT			"-*-*-*-r-*--16-*-*-*-*-*-iso8859-1"
-#else
-#define DEFCLASS		"XTerm"
-#define DEFFONT			"fixed"
 #endif
-#define DEFWIDEFONT		NULL	/* grab one which is 2x as wide */
-#define DEFWIDEBOLDFONT		NULL
-#define DEFXIMFONT		"*"
-#define DEFBOLDFONT		NULL	/* no bold font uses overstriking */
-#define DEFBORDER		2
-#define DEFFACENAME		NULL
-#define DEFFACESIZE		14
-
-#ifndef PROJECTROOT
-#define PROJECTROOT		"/usr/X11R6"
-#endif
-
-#define DEFLOCALEFILTER2(x)	#x
-#define DEFLOCALEFILTER1(x)	DEFLOCALEFILTER2(x)
-#define DEFLOCALEFILTER		DEFLOCALEFILTER1(PROJECTROOT) "/bin/luit"
